Crate doteur[][src]

General information

Doteur

A simple tool to draw your mysql relations from exports.

Warning : It is highly recommended to install graphviz prior using this tool For more information, please refer to either :

Modules

Functions

Check if the given input contains sql tables

Process the given file and return the output dot string

Write the output to the given file