Crate doteur[−][src]
General information

Doteur
A simple tool to draw your mysql relations from exports.

Modules
Functions
Check if the given input contains sql tables
Process the given file and return the output dot string
Write the output to the given file